"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const utils_1 = require("../utils");
function i18nCheck() {
    return (0, schematics_1.chain)([
        (tree, context) => {
            var _a, _b;
            const config = (0, utils_1.readConfig)(tree);
            context.logger.info(`Config = ${JSON.stringify(config)}`);
            context.logger.info(`Languages : ${config.languages.join(', ')}`);
            const dictionary = new Map();
            for (const lang of config.languages) {
                context.logger.info(`Search for '${lang}' files.`);
                const i18n = (0, utils_1.readLanguage)(tree, config.cwd, lang, true);
                dictionary.set(lang, i18n);
            }
            // Check i18n sizes
            let size = -1;
            let hasDifferentSize = false;
            const diffSizeReport = new Map();
            for (const lang of config.languages) {
                const i18nLang = dictionary.get(lang) || {};
                if (size === -1) {
                    const len = (_a = Object.keys(i18nLang)) === null || _a === void 0 ? void 0 : _a.length;
                    diffSizeReport.set(lang, len);
                    size = len;
                }
                else {
                    const len = (_b = Object.keys(i18nLang)) === null || _b === void 0 ? void 0 : _b.length;
                    diffSizeReport.set(lang, len);
                    if (size !== len) {
                        hasDifferentSize = true;
                    }
                }
            }
            context.logger.info(`I18n keys:`);
            diffSizeReport.forEach((value, key) => context.logger.info(`Language ${key} has ${value} keys.`));
            if (hasDifferentSize) {
                context.logger.error(`I18n files contains different number of keys.`);
            }
            return tree;
        }
    ]);
}
exports.default = i18nCheck;
//# sourceMappingURL=index.js.map