"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const utils_1 = require("../utils");
const SEPARATOR = ',';
const NEW_LINE = '\n';
function i18nExportCsv() {
    return (0, schematics_1.chain)([
        (tree, context) => {
            const config = (0, utils_1.readConfig)(tree);
            context.logger.info(`Config = ${JSON.stringify(config)}`);
            context.logger.info(`Languages : ${config.languages.join(', ')}`);
            const dictionary = new Map();
            let content = `"Key"`;
            for (const lang of config.languages) {
                context.logger.info(`Search for '${lang}' files.`);
                const i18n = (0, utils_1.readLanguage)(tree, config.cwd, lang);
                dictionary.set(lang, i18n);
                content += `${SEPARATOR}"${lang}"`;
            }
            content += NEW_LINE;
            const first = dictionary.get(config.languages[0]) || {};
            for (const key of Object.keys(first)) {
                content += `"${key}"`;
                for (const lang of config.languages) {
                    let value = '';
                    const l = dictionary.get(lang);
                    if (l !== undefined && l[key] !== undefined) {
                        value = l[key];
                    }
                    content += `${SEPARATOR}"${value}"`;
                }
                content += NEW_LINE;
            }
            save(tree, content, `${config.output}/languages.csv`);
            context.logger.info(`Save in '${config.output}/languages.csv'`);
            return tree;
        }
    ]);
}
exports.default = i18nExportCsv;
function save(tree, i18n, output) {
    if (tree.exists(output)) {
        tree.overwrite(output, i18n);
    }
    else {
        tree.create(output, i18n);
    }
}
//# sourceMappingURL=index.js.map