"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const utils_1 = require("../utils");
function i18nImportCsv() {
    return (0, schematics_1.chain)([
        (tree, context) => {
            const config = (0, utils_1.readConfig)(tree);
            context.logger.info(`Config = ${JSON.stringify(config)}`);
            context.logger.info(`Languages : ${config.languages.join(', ')}`);
            context.logger.info(`Construct Key to Path map`);
            const keyToPath = createIdToPathMap(tree, context, config);
            const langKeyValue = readCSV(tree, context, config);
            langKeyValue.forEach((langValue, langKey) => {
                langValue.forEach((value, key) => {
                    const path = keyToPath.get(key);
                    if (path) {
                        const dic = readLanguage(tree, path, langKey);
                        dic[key] = value;
                        (0, utils_1.saveLanguage)(tree, dic, `${path}/${langKey}.json`);
                    }
                });
            });
            return tree;
        }
    ]);
}
exports.default = i18nImportCsv;
function readCSV(tree, context, config) {
    const result = new Map();
    const buffer = tree.read(`${config.output}/languages.csv`);
    if (buffer) {
        const languages = [];
        const rows = buffer.toString().split(/\r?\n/);
        rows.forEach((row, rowIndex) => {
            // Header read
            if (rowIndex === 0) {
                const columns = row.split('","');
                columns.forEach((column, columnIndex) => {
                    if (columnIndex > 0) {
                        const lang = removeQuote(column);
                        languages.push(lang);
                        result.set(lang, new Map());
                    }
                });
            }
            else {
                const columns = row.split('","');
                let i18nKey = '';
                columns.forEach((column, columnIndex) => {
                    if (columnIndex === 0) {
                        i18nKey = removeQuote(column);
                    }
                    else {
                        const lang = languages[columnIndex - 1];
                        const langMap = result.get(lang);
                        if (langMap) {
                            if (langMap.has(i18nKey)) {
                                context.logger.warn(`The Key '${i18nKey}' is declared more then one time in the csv file.`);
                            }
                            langMap.set(i18nKey, removeQuote(column));
                        }
                    }
                });
            }
        });
    }
    return result;
}
function readLanguage(tree, cwd, lang) {
    let i18n = {};
    const filePath = `${cwd}/${lang}.json`;
    if (tree.exists(filePath)) {
        const buffer = tree.read(filePath);
        if (buffer) {
            i18n = JSON.parse(buffer.toString());
        }
    }
    return i18n;
}
function createIdToPathMap(tree, context, config) {
    const keyToPath = new Map();
    const lang = config.languages[0];
    tree.getDir(config.cwd)
        .visit((filePath) => {
        if (filePath.search(`/${lang}.json$`) === -1) {
            return;
        }
        const dirPath = filePath.substr(0, filePath.length - lang.length - 5);
        const buffer = tree.read(filePath);
        if (buffer) {
            const i18n = JSON.parse(buffer.toString());
            for (const i18nKey in i18n) {
                if (keyToPath.has(i18nKey)) {
                    context.logger.warn(`The Key '${i18nKey}' is declared more then one time. Paths : '${keyToPath.get(i18nKey)}' and '${dirPath}'.`);
                }
                else {
                    keyToPath.set(i18nKey, dirPath);
                }
            }
        }
    });
    return keyToPath;
}
function removeQuote(text) {
    let result = text;
    if (result.charAt(0) === '"') {
        result = result.substring(1);
    }
    if (result.charAt(result.length - 1) === '"') {
        result = result.slice(0, -1);
    }
    return result;
}
//# sourceMappingURL=index.js.map