"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const utils_1 = require("../utils");
const fs_1 = require("fs");
const proxy_agent_1 = require("proxy-agent");
const node_fetch_1 = require("node-fetch");
const CURRENT_FOLDER = 'projects/tools/schematics/i18n-localess-diff';
function i18nLocalessDiff(options) {
    return (0, schematics_1.chain)([
        // Download locales in a temporary folder
        (tree, context) => __awaiter(this, void 0, void 0, function* () {
            const config = (0, utils_1.readConfig)(tree);
            // context.logger.info(`Config = ${JSON.stringify(config)}`);
            context.logger.info(`Languages : ${config.languages.join(', ')}`);
            for (const lang of config.languages) {
                const hostUrl = `${options.host}/api/v1/spaces/${options.space}/translations/${lang}.json`;
                context.logger.info(`Downloading : ${hostUrl}`);
                let content = '{}';
                // handle local tests
                if (options.host === 'local') {
                    content = (0, fs_1.readFileSync)(`${CURRENT_FOLDER}/${lang}.json`);
                }
                else {
                    const fetchOptions = {
                        redirect: 'follow'
                    };
                    if ((0, utils_1.proxyURIFromEnv)()) {
                        fetchOptions.agent = new proxy_agent_1.ProxyAgent();
                    }
                    try {
                        const res = yield (0, node_fetch_1.default)(hostUrl, fetchOptions);
                        if (res.ok) {
                            content = yield res.text();
                        }
                    }
                    catch (thrown) {
                        context.logger.error(`Downloading error from: ${hostUrl} `);
                        context.logger.error(thrown);
                    }
                }
                tree.create(`${config.output}/tmp/${lang}.json`, content);
            }
        }),
        // Work
        (tree, context) => {
            const config = (0, utils_1.readConfig)(tree);
            for (const lang of config.languages) {
                context.logger.info(`Collecting data for '${lang}'...`);
                const local = (0, utils_1.extractKeyValue)(tree, config.cwd, lang);
                const remote = (0, utils_1.extractKeyValue)(tree, `${config.output}/tmp`, lang);
                const allKeys = new Set([...remote.keys(), ...local.keys()]);
                const diff = [];
                allKeys.forEach(key => {
                    const localValue = local.get(key);
                    const cloudValue = remote.get(key);
                    if (localValue && cloudValue) {
                        if (localValue !== cloudValue) {
                            diff.push({
                                key,
                                local: localValue,
                                cloud: cloudValue
                            });
                        }
                    }
                    else {
                        diff.push({
                            key,
                            local: localValue,
                            cloud: cloudValue
                        });
                    }
                });
                context.logger.info(`Language '${lang}' differences :`);
                // console.log(`Language '${lang}' differences :`);
                console.table(diff);
            }
        },
        // Clean up temporary folder
        (tree, context) => {
            // console.log(`Cleanup temporary files ...`);
            context.logger.info(`Cleanup temporary files ...`);
            const config = (0, utils_1.readConfig)(tree);
            for (const lang of config.languages) {
                const path = `${config.output}/tmp/${lang}.json`;
                if (tree.exists(path)) {
                    tree.delete(path);
                }
            }
        }
    ]);
}
exports.default = i18nLocalessDiff;
//# sourceMappingURL=index.js.map