"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.proxyURIFromEnv = exports.saveLanguage = exports.updateI18nFile = exports.extractKeyValue = exports.extractKeyPath = exports.readLanguage = exports.readConfig = void 0;
const models_1 = require("./models");
function readConfig(tree) {
    const file = tree.read('lessify.json');
    let config;
    if (file) {
        config = JSON.parse(file.toString());
        return Object.assign(Object.assign({}, models_1.defaultConfig), config);
    }
    return models_1.defaultConfig;
}
exports.readConfig = readConfig;
/**
 * Extract language in one JSON.
 */
function readLanguage(tree, cwd, lang, duplicateCheck = false) {
    let i18n = {};
    tree.getDir(cwd)
        .visit((filePath) => {
        if (filePath.search(`/${lang}.json$`) === -1) {
            return;
        }
        const buffer = tree.read(filePath);
        if (buffer) {
            const read = JSON.parse(buffer.toString());
            if (duplicateCheck) {
                for (const key of Object.keys(read)) {
                    if (i18n[key] !== undefined) {
                        console.warn(`The key [${key}] is used multiple times. One of file is '${filePath}'.`);
                    }
                }
            }
            i18n = Object.assign(Object.assign({}, i18n), read);
        }
    });
    return i18n;
}
exports.readLanguage = readLanguage;
/**
 * Extract Key and Path.
 */
function extractKeyPath(tree, cwd, lang) {
    const keyPath = new Map();
    tree.getDir(cwd)
        .visit((filePath) => {
        if (filePath.search(`/${lang}.json$`) === -1) {
            return;
        }
        const buffer = tree.read(filePath);
        if (buffer) {
            const read = JSON.parse(buffer.toString());
            for (const key of Object.keys(read)) {
                keyPath.set(key, filePath);
            }
        }
    });
    return keyPath;
}
exports.extractKeyPath = extractKeyPath;
/**
 * Extract Key and Value.
 */
function extractKeyValue(tree, cwd, lang) {
    const keyValue = new Map();
    tree.getDir(cwd)
        .visit((filePath) => {
        if (filePath.search(`/${lang}.json$`) === -1) {
            return;
        }
        const buffer = tree.read(filePath);
        if (buffer) {
            const read = JSON.parse(buffer.toString());
            for (const key of Object.keys(read)) {
                keyValue.set(key, read[key]);
            }
        }
    });
    return keyValue;
}
exports.extractKeyValue = extractKeyValue;
/**
 * Update i18n file
 */
function updateI18nFile(tree, filePath, key, value) {
    const buffer = tree.read(filePath);
    if (buffer) {
        const read = JSON.parse(buffer.toString());
        read[key] = value;
        tree.overwrite(filePath, JSON.stringify(read, null, 2));
    }
}
exports.updateI18nFile = updateI18nFile;
/**
 * Save language Dictionary in file
 */
function saveLanguage(tree, i18n, output) {
    if (tree.exists(output)) {
        tree.overwrite(output, JSON.stringify(i18n, null, 2));
    }
    else {
        tree.create(output, JSON.stringify(i18n, null, 2));
    }
}
exports.saveLanguage = saveLanguage;
function proxyURIFromEnv() {
    return (process.env.HTTPS_PROXY ||
        process.env.https_proxy ||
        process.env.HTTP_PROXY ||
        process.env.http_proxy ||
        undefined);
}
exports.proxyURIFromEnv = proxyURIFromEnv;
//# sourceMappingURL=utils.js.map